@@ -32,7 +32,6 @@ export function componentInit(args) {
   components[component.id] = component;
 
   component.setModelValues();
-  component.setDbModelValues();
 }
 
 /**
@@ -121,3 +120,11 @@ export function addEventListener(eventName, callback) {
 
   lifecycleEvents[eventName].push(callback);
 }
+
+/**
+ * Trigger a component update by dispatching an event for a particular element.
+ */
+export function trigger(componentNameOrKey, elementKey) {
+  const component = getComponent(componentNameOrKey);
+  component.trigger(elementKey);
+}
